@@ -1226,7 +1226,12 @@ function clearSearchMatches() {
 /**
  * Scroll down to the next node that matched a search.
  */
-function nextSearchMatch() {
+function nextSearchMatch(e, fromSearch) {
+    if (!fromSearch) {
+        if ($("#searchInc").prop('checked')) {
+            doSearch();
+        }
+    }
     scrollToNext(".searchmatch");
 }
 
@@ -1365,22 +1370,23 @@ function saveSearch() {
  * @private
  */
 function doSearch () {
-    // TODO: need to save val of incremental acorss searches
-    clearSearchMatches();
+    // TODO: need to save val of incremental across searches
     var searchnodes = $("#searchnodes");
     saveSearch();
     hideDialogBox();
     var searchCtx = $(".snode"); // TODO: remove sn0
-    var incremental = $("#searchInc").val() == "on";
+    var incremental = $("#searchInc").prop('checked');
 
     if (incremental && $(".searchmatch").length > 0) {
         var lastMatchTop = $(".searchmatch").last().offset().top;
-        searchCtx.filter(function () {
+        searchCtx = searchCtx.filter(function () {
             // TODO: do this with faster document position dom call
             return $(this).offset().top > lastMatchTop;
         });
     }
 
+    clearSearchMatches();
+
     for (var i = 0; i < searchCtx.length; i++) {
         var res = interpretSearchNode(searchnodes, searchCtx[i]);
         if (res) {
@@ -1390,7 +1396,11 @@ function doSearch () {
             }
         }
     }
-    nextSearchMatch();
+    nextSearchMatch(null, true);
+    // TODO: when reaching the end of the document in incremental search,
+    // don't dehighlight the last match, but print a nice message
+
+    // TODO: need a way to go back in incremental search
 }
 
 /**
@@ -1523,6 +1533,9 @@ function search() {
  *
  * The movement operation must not change the text of the token.
  *
+ * Empty categories are not allowed to be moved as a leaf.  However, a
+ * non-terminal containing only empty categories can be moved.
+ *
  * @param {DOM Node} parent the parent node to move selection under
  *
  * @returns {Boolean} whether the operation was successful
@@ -1539,7 +1552,8 @@ function moveNode(parent) {
     var nodeMoved;
     if (!isPossibleTarget(parent) || // can't move under a tag node
         $(startnode).parent().children().length == 1 || // can't move an only child
-        $(parent).parents().is(startnode) // can't move under one's own child
+        $(parent).parents().is(startnode) || // can't move under one's own child
+        isEmptyNode(startnode) // can't move an empty leaf node by itself
        )
     {
         clearSelection();
@@ -1926,6 +1940,19 @@ function pruneNode() {
             } else {
                 touchTree($(startnode));
             }
+            var idx = getIndex($(startnode));
+            if (idx > 0) {
+                var root = $(getTokenRoot($(startnode)));
+                var sameIdx = root.find('.snode').filter(function () {
+                    return getIndex($(this)) == idx;
+                }).not(startnode);
+                if (sameIdx.length == 1) {
+                    var osn = startnode;
+                    startnode = sameIdx.get(0);
+                    coIndex();
+                    startnode = osn;
+                }
+            }
             $(startnode).remove();
             startnode = endnode = null;
             updateSelection();
@@ -2887,6 +2914,6 @@ function resetLabelClasses(alertOnError) {
 // " "toggleStringExtension" "lookupNextLabel" "commentTypes\
 // " "invisibleCategories" "invisibleRootCategories" "ipnodes" "messageHistory\
 // " "scrollToNext" "clearTimeout" "logDetail" "hasLemma" "getLemma\
-// " "logDetail")
+// " "logDetail" "isEmptyNode")
 // indent-tabs-mode: nil
 // End:
