@@ -198,13 +198,13 @@ function displayError(html) {
  */
 function scrollToNext(selector) {
     var docViewTop = $(window).scrollTop();
-    var docViewMiddle = docViewTop + $(window).height() / 2;
     var nextError = $(selector).filter(
         function () {
-            return $(this).offset().top > docViewMiddle;
+            // Magic number alert!  Not sure if the +5 is needed...
+            return $(this).offset().top > docViewTop + 5;
         }).first();
     if (nextError.length == 1) {
-        window.scroll(0, nextError.offset().top - $(window).height() * 0.25);
+        window.scroll(0, nextError.offset().top);
         return nextError;
     }
     return undefined;
@@ -226,11 +226,33 @@ function hasLemma(node) {
     return node.children(".wnode").children(".lemma").length == 1;
 }
 
+/**
+ * Test whether a given node is empty, i.e. a trace, comment, or other empty
+ * category.
+ *
+ * @param {DOM Node} node
+ * @returns {Boolean}
+ */
+function isEmptyNode(node) {
+    if (!isLeafNode(node)) {
+        return false;
+    }
+    if (getLabel($(node)) == "CODE") {
+        return true;
+    }
+    var text = wnodeString(node);
+    if (text.startsWith("*") || text.split("-")[0] == "0") {
+        return true;
+    }
+    return false;
+}
+
 /**
  * Test whether a string is empty, i.e. a trace, comment, or other empty
  * category.
  *
  * @param {String} text the text to test
+ * @returns {Boolean}
  */
 function isEmpty (text) {
     // TODO(AWE): should this be passed a node instead of a string, and then
